package at.ac.uibk.gitsearch.web.rest;

import java.io.IOException;

import javax.websocket.server.PathParam;

import org.codeability.sharing.plugins.api.ShoppingBasket;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import at.ac.uibk.gitsearch.es.model.DocumentInfo;
import at.ac.uibk.gitsearch.service.ShoppingBasketService;
import at.ac.uibk.gitsearch.service.ShoppingBasketService.ShoppingBasketInfoDTO;
import at.ac.uibk.gitsearch.service.ShoppingBasketService.ShoppingBasketRedirectInfoDTO;
import at.ac.uibk.gitsearch.service.dto.SearchInputDTO;

/**
 * REST controller for managing {@link DocumentInfo}.
 */
@RestController
@RequestMapping("/api")
@Transactional
public class PluginInterfaceResource {

	private final Logger log = LoggerFactory.getLogger(PluginInterfaceResource.class);

	@Autowired
	private ShoppingBasketService basketService;
	
    @PostMapping("/shoppingBasket/getPluginRedirectInfos") 
	public ShoppingBasketRedirectInfoDTO getRedirectInfos(@RequestBody ShoppingBasketInfoDTO basketInfo) {
    	return basketService.getRedirectInfo(basketInfo, "http://...");
    }
	
    /**
     * {@code SEARCH  /search/page-details} : search for the searchResults corresponding
     *  to the query.
     *
	 * @param query the query of the searchResult search.
	 * @return the result of the search.
     */
    @GetMapping("/pluginIF/getBasket/{basketToken}") 
    public ShoppingBasket searchPageDetails(
    		@PathParam("basketToken") String basketToken) throws IOException {
        log.debug("REST request for basket  {}", basketToken);
        return basketService.getBasket(basketToken);
    }

}
